@@ -1,11 +1,13 @@
 from .services.team_service import TeamService
 from .services.fixture_service import FixtureService
-from .services.xgoals_service import XGoalsService
+from .services.xg_service import XGService
 from .services.fixture_stats_service import FixtureStatsService
 from .services.lineups_service import LineupsService
 from .services.team_ratings_service import TeamRatingsService
 from .services.odds_service import OddsService
 from .services.team_stats_service import TeamStatsService
+from .services.uefa_ranking_service import UEFARankingService
+from .services.elo_service import EloService
 
 from .models.fixture import Fixture
 from .models.fixture_stats import FixtureStats
@@ -14,7 +16,9 @@ from .models.team import Team
 from .models.lineups import Lineups
 from .models.odds import Odds
 from .models.team_ratings import TeamRatings
-from .models.xgoals import XGoals
-from .models.team_stats import TeamStats
+from .models.xg import XG
+from .models.teams_stats import TeamStats
 from .models.team_lineups import TeamLineups
 from .models.league import League
+from .models.uefa_ranking import UEFARanking
+from .models.elo import Elo
