@@ -2,9 +2,8 @@ import os
 from pymongo import MongoClient
 
 # Load environment variables or set defaults
-MONGO_URI = os.getenv('MONGO_URI', 'mongodb://192.168.0.250:27017/')
-#MONGO_URI = os.getenv('MONGO_URI', 'mongodb://localhost:27017/')
-#MONGO_DB_NAME = os.getenv('MONGO_DB_NAME', 'local')
+# MONGO_URI = os.getenv('MONGO_URI', 'mongodb://192.168.0.250:27017/')
+MONGO_URI = os.getenv('MONGO_URI', 'mongodb://localhost:27017/')
 
 
 class MongoDB:
