@@ -10,18 +10,20 @@ class FixtureStatsRepository(MongoDBBaseRepository):
     def __init__(self, db_name):
         super().__init__(db_name)
 
-    def upsert_many_fixture_stats(self, fixture_stats):
+    def upsert_many_fixture_stats(self, fixture_stats: list):
         self.bulk_upsert_documents('fixtures_stats', fixture_stats)
-        logger.info('Upserted fixture stats data')
+        logger.debug('Upserted fixture stats data')
 
     def get_fixture_stats(self, fixture_id: int) -> dict:
         query = {'parameters.fixture': fixture_id}
+
         stats = self.find_document('fixtures_stats', query)
-        logger.info(f'Fetching stats for fixture {fixture_id}')
+        logger.debug(f'Fetching stats for fixture {fixture_id}')
         return stats
 
-    def get_team_fixture_stats(self, fixture_ids: List[int]) -> list:
+    def get_many_fixture_stats(self, fixture_ids: List[int]) -> list:
         query = {'parameters.fixture': {'$in': fixture_ids}}
+
         fixture_stats = self.find_documents('fixtures_stats', query)
-        logger.info(f'Fetching lineups for fixtures {fixture_ids}')
+        logger.debug(f'Fetching lineups for fixtures {fixture_ids}')
         return fixture_stats
