@@ -12,18 +12,20 @@ class InjuryRepository(MongoDBBaseRepository):
     def __init__(self):
         super().__init__(self.DB_NAME)
 
-    def upsert_many_injuries(self, injuries):
+    def upsert_many_injuries(self, injuries: list):
         self.bulk_upsert_documents('injuries', injuries)
-        logger.info('Upsert fixture stats data')
+        logger.debug('Upsert fixture stats data')
 
-    def get_injuries(self, fixture_id: int) -> list:
+    def get_injuries(self, fixture_id: int) -> dict:
         query = {'parameters.fixture': fixture_id}
+
         injuries = self.find_document('injuries', query)
-        logger.info(f'Fetching injuries for fixture {fixture_id}')
+        logger.debug(f'Fetching injuries for fixture {fixture_id}')
         return injuries
 
-    def get_team_injuries(self, fixture_ids: List[int]) -> list:
+    def get_many_injuries(self, fixture_ids: List[int]) -> list:
         query = {'parameters.fixture': {'$in': fixture_ids}}
+
         injuries = self.find_documents('injuries', query)
-        logger.info(f'Fetching lineups for fixtures {fixture_ids}')
+        logger.debug(f'Fetching lineups for fixtures {fixture_ids}')
         return injuries
