@@ -1,12 +1,9 @@
-import logging
 from typing import Optional
 
 from buco_db_controller.models.lineups import Lineups
 from buco_db_controller.repositories.lineups_repository import LineupsRepository
 from buco_db_controller.services.fixture_service import FixtureService
 
-LOGGER = logging.getLogger(__name__)
-
 
 class LineupsService:
     def __init__(self):
@@ -15,7 +12,6 @@ class LineupsService:
 
     def upsert_many_lineups(self, fixture_lineups: list):
         self.lineups_repository.bulk_upsert_documents('lineups', fixture_lineups)
-        LOGGER.info('Upserted fixture stats data')
 
     def get_lineups(self, fixture_id: int) -> Optional[Lineups]:
         response = self.lineups_repository.get_lineups(fixture_id)
