@@ -1,13 +1,14 @@
 from typing import Union, List
 
 from buco_db_controller.models.team import Team
-from buco_db_controller.models.team_stats import TeamStats
+from buco_db_controller.repositories.fixture_repository import FixtureRepository
 from buco_db_controller.repositories.team_repository import TeamRepository
 
 
 class TeamService:
     def __init__(self):
         self.team_repository = TeamRepository()
+        self.fixture_repository = FixtureRepository()
 
     def upsert_many_teams(self, teams: List[dict]):
         self.team_repository.upsert_many_teams(teams)
@@ -31,3 +32,17 @@ class TeamService:
         team_ids = list(map(int, set(team_ids)))
         team_ids.sort()
         return team_ids
+
+    def count_consecutive_years_in_league(self, team_id: int, league_id: int, current_season: int) -> int:
+        seasons_to_check = list(range(2014, current_season + 1))
+        consecutive_years = 0
+
+        for season in seasons_to_check:
+            fixtures = self.fixture_repository.get_team_fixtures(team_id, league_id, season)
+
+            if fixtures and fixtures['data'][0]['league']['id'] == league_id:
+                consecutive_years += 1
+            else:
+                consecutive_years = 0
+
+        return consecutive_years
